package sun.util.locale.provider;

import java.util.Locale;
import java.util.Set;
import java.util.spi.CalendarDataProvider;

public class CalendarDataProviderImpl extends CalendarDataProvider implements AvailableLanguageTags
{
    private final LocaleProviderAdapter.Type type;
    private final Set<String> langtags;
    
    public CalendarDataProviderImpl(LocaleProviderAdapter.Type type, Set<String> langtags) {
        this.type = type;
        this.langtags = langtags;
    }
    
    @Override
    public int getFirstDayOfWeek(Locale locale) {
        return LocaleProviderAdapter.forType(this.type).getLocaleResources(locale).getCalendarData("firstDayOfWeek");
    }
    
    @Override
    public int getMinimalDaysInFirstWeek(Locale locale) {
        return LocaleProviderAdapter.forType(this.type).getLocaleResources(locale).getCalendarData("minimalDaysInFirstWeek");
    }
    
    @Override
    public Locale[] getAvailableLocales() {
        return LocaleProviderAdapter.toLocaleArray(this.langtags);
    }
    
    @Override
    public Set<String> getAvailableLanguageTags() {
        return this.langtags;
    }
}
